package ## no critic: Modules::RequireFilenameMatchesPackage
    # hide from PAUSE
    TableDataRole::Business::ID::BPOM::FoodAdditive;

use 5.010001;
use strict;
use warnings;

use Role::Tiny;
with 'TableDataRole::Source::CSVInFile';

around new => sub {
    my $orig = shift;

    my $filename;
  FIND_CSV:
    {
      TRY_PROJ_DIR: {
            $filename = __FILE__;
            $filename =~ s!(.+)([/\\].+)!$1!;
            $filename .= "/../../../../../share/merged.csv";
            last FIND_CSV if -f $filename;

        };
        TRY_DIST_SHARE_DIR: {
              require File::ShareDir;
              my $dist_dir = File::ShareDir::dist_dir('TableData-Business-ID-BPOM-FoodAdditive');
              $filename = "$dist_dir/merged.csv";
              last FIND_CSV if -f $filename;
          }
        die "Can't find merged.csv anywhere";
    }

    $orig->(@_, filename => $filename);
};

package TableData::Business::ID::BPOM::FoodAdditive;

use 5.010001;
use strict;
use warnings;

use Role::Tiny::With;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2024-04-10'; # DATE
our $DIST = 'TableData-Business-ID-BPOM-FoodAdditive'; # DIST
our $VERSION = '20240409.0.0'; # VERSION

with 'TableDataRole::Business::ID::BPOM::FoodAdditive';

our %STATS = ("num_rows",55422,"num_columns",11); # STATS

1;
# ABSTRACT: Food additives in BPOM

__END__

=pod

=encoding UTF-8

=head1 NAME

TableDataRole::Business::ID::BPOM::FoodAdditive - Food additives in BPOM

=head1 VERSION

This document describes version 20240409.0.0 of TableDataRole::Business::ID::BPOM::FoodAdditive (from Perl distribution TableData-Business-ID-BPOM-FoodAdditive), released on 2024-04-10.

=head1 SYNOPSIS

To use from Perl code:

 use TableData::Business::ID::BPOM::FoodAdditive;

 my $td = TableData::Business::ID::BPOM::FoodAdditive->new;

 # Iterate rows of the table
 $td->each_row_arrayref(sub { my $row = shift; ... });
 $td->each_row_hashref (sub { my $row = shift; ... });

 # Get the list of column names
 my @columns = $td->get_column_names;

 # Get the number of rows
 my $row_count = $td->get_row_count;

See also L<TableDataRole::Spec::Basic> for other methods.

To use from command-line (using L<tabledata> CLI):

 # Display as ASCII table and view with pager
 % tabledata Business::ID::BPOM::FoodAdditive --page

 # Get number of rows
 % tabledata --action count_rows Business::ID::BPOM::FoodAdditive

See the L<tabledata> CLI's documentation for other available actions and options.

=head1 DESCRIPTION

Keyword: BPOM, pangan olahan, BTP, bahan tambahan pangan

=head1 TABLEDATA STATISTICS

 +-------------+-------+
 | key         | value |
 +-------------+-------+
 | num_columns | 11    |
 | num_rows    | 55422 |
 +-------------+-------+

The statistics is available in the C<%STATS> package variable.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/TableData-Business-ID-BPOM-FoodAdditive>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-TableData-Business-ID-BPOM-FoodAdditive>.

=head1 SEE ALSO

L<TableData::Business::ID::BPOM::FoodIngredientRBA>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2024 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableData-Business-ID-BPOM-FoodAdditive>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
